comments.Comment (Comment) — amici1

# `comments.Comment` (Comment)

Comment(id, modified, created, user, owner_type, owner_id, body, body_short_preview, body_full_preview, reply_to, private, comment_type)

Master tables : comments.AllComments (Comments), comments.Comments (Comments), comments.CommentsByX (Comments), comments.MyComments (My Comments), comments.RecentComments (Recent comments)

Slave tables : comments.CommentsByMentioned (Mentioned in), comments.RepliesByComment (Replies), courses.ActivitiesByLine (Activities), courses.ActivitiesBySlot (Activities), courses.ActivitiesByTopic (Activities), courses.EnrolmentsByCourse (Enrolments), courses.LinesByTopic (Activity lines)

Database fields:

- ID (id) : See `<django.db.models.fields.BigAutoField: id>`.

- Modified (modified) : The time when this database object was last modified.

- Created (created) : The time when this object was created.

- Author (user) : The author of the comment.

- Topic (type) (owner_type) : See `<django.db.models.fields.related.ForeignKey: owner_type>`.

- Topic (object) (owner_id) : See `<lino.modlib.gfks.fields.GenericForeignKeyIdField: owner_id>`.

- Body (body) : The full body text of your comment.

- Preview (body_short_preview) : A read-only preview of the first paragraph of body.

- Preview (full) (body_full_preview) : A read-only full preview of body.

- Reply to (reply_to) : See `<django.db.models.fields.related.ForeignKey: reply_to>`.

- Private (private) : See `<django.db.models.fields.BooleanField: private>`.

- Comment Type (comment_type) : See `<django.db.models.fields.related.ForeignKey: comment_type>`.

- Emotion (my_emotion) : See `lino.modlib.comments.models.Comment.my_emotion`.

- (None) (card_summary) : See `lino.modlib.comments.models.Comment.card_summary`.

- Created (created_natural) : See `lino.modlib.comments.models.Comment.created_natural`.

- Name (name_column) : See `lino.modlib.comments.models.Comment.name_column`.

- (None) (navigation_panel) : See `lino.modlib.comments.models.Comment.navigation_panel`.

- Workflow (workflow_buttons) : List of actions that change the workflow state of this object.

- (None) (overview) : See `lino.modlib.comments.models.Comment.overview`.

- Pick Emotion (pick_my_emotion) : See `lino.modlib.comments.models.Comment.pick_my_emotion`.

Referenced from comments.Comment.reply_to, comments.Mention.comment, comments.Reaction.comment

## Database fields

Internal name | Verbose name | Help text
--- | --- | ---
id | ID |
modified | Modified | The time when this database object was last modified.
created | Created | The time when this object was created.
user | Author | The author of the comment.
owner_type | Topic (type) |
owner_id | Topic (object) |
body | Body | The full body text of your comment.
body_short_preview | Preview | A read-only preview of the first paragraph of body.
body_full_preview | Preview (full) | A read-only full preview of body.
reply_to | Reply to |
private | Private |
comment_type | Comment Type |
owner | Topic | The topic this comment is about. This field is a Generic Foreign Key, i.e. users can basically comment on any database object. It is however the application developer who decides where comments can be created and how they are being displayed.
my_emotion | Emotion |
card_summary | None |
created_natural | Created |
name_column | Name |
navigation_panel | None |
workflow_buttons | Workflow | List of actions that change the workflow state of this object.
overview | None |
pick_my_emotion | Pick Emotion |